from lino.projects.std.settings import *
#~ class Lino(Lino):
    #~ user_model = None
SITE = Site(globals(), ['lino.test_apps.mti'])
